@@ -14,14 +14,14 @@
 */
 
 /**
- * Copyright 2003 LUT. .
+ * Copyright 2003-2011 LUT. .
  *
  * @name BTPlugin.cc
  * @memo Bluetooth implementation of PeerHood's plugin interface.
  *
- * @version 0.1
+ * @version 0.21
  * date     08.04.2003
- * change   5.5.2004
+ * change   15.04.2011
  */
 
 #include <sys/ioctl.h>
@@ -321,7 +321,7 @@ void CBTPlugin::SetState(bool aActive)
 		iActive = aActive;
 		DBG("CBTPlugin::SetState: new state: %s", aActive ? "active" : "passive");
 	}
-	else DBG("CBTPlugin::SetState: No change in activity state.");
+	//else DBG("CBTPlugin::SetState: No change in activity state.");
 	
 	if(aActive == true && iInSdp == false && iStarted == true)
 	{
@@ -1782,18 +1782,29 @@ void CBTPlugin::SetAdapter(const std::string& aInterface, int aId)
 	}
 	else
 	{
-		// Set the plugin to inactive
-		SetState(false);
+		// Plugin is not active, no need to change state
+		if(!iActive)
+		{
+			// Set new values
+			iNDevice = std::string(aInterface);
+			iDeviceId = aId;
+		}
+		// Was active
+		else
+		{
+			// Set the plugin to inactive
+			SetState(false);
 		
-		// Give threads some time to proceed to wait state
-		sleep(1);
+			// Give threads some time to proceed to wait state
+			sleep(1);
 		
-		// Set new values
-		iNDevice = aInterface;
-		iDeviceId = aId;
+			// Set new values
+			iNDevice = std::string(aInterface);
+			iDeviceId = aId;
 		
-		// Set plugin to active
-		SetState(true);
+			// Set plugin to active
+			SetState(true);
+		}
 	}
 }
 
